==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/ScatterSplineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSplineSeriesView = /*@__PURE__*/ (() => {
    class ScatterSplineSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dg = new Path();
            this.df = new Path();
        }
        as() {
            super.as();
            if (!this.q) {
                this.e.gk = Defaults.x;
                this.b1.p0 = Defaults.e;
            }
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            this.df.ak = this.dg.ak;
            let a = this.bo();
            this.df._stroke = a;
            this.df.ac = this.e.fn + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.df);
                }
                else {
                    a.s(this.dg);
                }
            }
        }
        c4(a) {
            super.c4(a);
            this.dg.ak = null;
            this.df.ak = null;
        }
        al(a) {
            super.al(a);
            this.e.a7.exportPathData(a, this.dg, "shape", ["Main"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.o0 = a;
            this.e.gm = 3;
            this.e.gn = 1;
            this.e.go = 4;
            this.e.e3 = false;
        }
    }
    ScatterSplineSeriesView.$t = /*@__PURE__*/ markType(ScatterSplineSeriesView, 'ScatterSplineSeriesView', ScatterBaseView.$);
    return ScatterSplineSeriesView;
})();

==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/ScatterSplineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSplineSeriesView = /*@__PURE__*/ (() => {
    class ScatterSplineSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dg = new Path();
            this.df = new Path();
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.qd = Defaults.e;
            }
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            this.df.ak = this.dg.ak;
            let a = this.bo();
            this.df._stroke = a;
            this.df.ac = this.e.fu + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.df);
                }
                else {
                    a.s(this.dg);
                }
            }
        }
        c4(a) {
            super.c4(a);
            this.dg.ak = null;
            this.df.ak = null;
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.dg, "shape", ["Main"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pb = a;
            this.e.gw = 3;
            this.e.gx = 1;
            this.e.gy = 4;
            this.e.e7 = false;
        }
    }
    ScatterSplineSeriesView.$t = /*@__PURE__*/ markType(ScatterSplineSeriesView, 'ScatterSplineSeriesView', ScatterBaseView.$);
    return ScatterSplineSeriesView;
})();
